==> flow-client-1.4.8-sources.jar: com/vaadin/flow/dom/ElementConstants.java <==
/*
 * Copyright 2000-2018 Vaadin Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.vaadin.flow.dom;

/**
 * Constants for common element attribute, property, style names.
 *
 * @author Vaadin Ltd
 * @since 1.0
 */
public class ElementConstants {

    /**
     * The style property for width.
     */
    public static final String STYLE_WIDTH = "width";
    /**
     * The style property for min-width.
     */
    public static final String STYLE_MIN_WIDTH = "min-width";
    /**
     * The style property for max-width.
     */
    public static final String STYLE_MAX_WIDTH = "max-width";
    /**
     * The style property for height.
     */
    public static final String STYLE_HEIGHT = "height";
    /**
     * The style property for min-height.
     */
    public static final String STYLE_MIN_HEIGHT = "min-height";
    /**
     * The style property for max-height.
     */
    public static final String STYLE_MAX_HEIGHT = "max-height";
    /**
     * The style property for color.
     */
    public static final String STYLE_COLOR = "color";

    private ElementConstants() {
        // Constants only
    }

}

==> flow-client-23.3.31-sources.jar: com/vaadin/flow/dom/ElementConstants.java <==
/*
 * Copyright 2000-2022 Vaadin Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.vaadin.flow.dom;

/**
 * Constants for common element attribute, property, style names.
 *
 * @author Vaadin Ltd
 * @since 1.0
 */
public class ElementConstants {

    /**
     * The style property for width.
     */
    public static final String STYLE_WIDTH = "width";
    /**
     * The style property for min-width.
     */
    public static final String STYLE_MIN_WIDTH = "min-width";
    /**
     * The style property for max-width.
     */
    public static final String STYLE_MAX_WIDTH = "max-width";
    /**
     * The style property for height.
     */
    public static final String STYLE_HEIGHT = "height";
    /**
     * The style property for min-height.
     */
    public static final String STYLE_MIN_HEIGHT = "min-height";
    /**
     * The style property for max-height.
     */
    public static final String STYLE_MAX_HEIGHT = "max-height";
    /**
     * The style property for color.
     */
    public static final String STYLE_COLOR = "color";
    /**
     * The label property.
     */
    public static final String LABEL_PROPERTY_NAME = "label";
    /**
     * The aria-label property.
     */
    public static final String ARIA_LABEL_PROPERTY_NAME = "aria-label";

    private ElementConstants() {
        // Constants only
    }

}
